Module app

Module app 

Application lifecycle and resource ownership.

Apps lease capabilities from a Registry when they are created and must return every lease when they are released. This makes resource availability predictable as the platform switches between apps.

Traits

App
An application that can be selected and run by the xpanse firmware.