Module driver

Module driver 

Module driver traits.

A driver identifies its hardware through DriverMeta::ID, consumes the detected module’s crate::gpio_bank::GpioBank, initializes any buses it needs, and publishes app-facing capabilities in a crate::registry::Registry.

Enums

DriverError
Error returned when a module driver cannot be initialized.

Traits

Driver
Initializes a module and publishes the capabilities it provides.
DriverMeta
Static metadata used to match a driver to a detected module.