App- and driver-facing hardware capabilities.
These interfaces hide board-specific implementations behind stable resource types that can be registered by drivers and leased by apps.
App- and driver-facing hardware capabilities.
These interfaces hide board-specific implementations behind stable resource types that can be registered by drivers and leased by apps.