pub enum FrameBufferError {
InvalidDimensions,
}Expand description
Error returned when creating or using a frame buffer.
Variants
InvalidDimensions
The supplied dimensions are zero or do not match the storage slice length.