ResourceSet

Trait ResourceSet 

pub trait ResourceSet: ResourceSetSealed {
    type Leases;
}
A tuple of distinct resource types allocated atomically.

Each requested type is assigned to a different physical resource group.

Required Associated Types

type Leases

Tuple of leases returned when the complete set is acquired.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T1: 'static + Send, T2: 'static + Send, T3: 'static + Send, T4: 'static + Send, T5: 'static + Send, T6: 'static + Send, T7: 'static + Send, T8: 'static + Send, T9: 'static + Send, T10: 'static + Send> ResourceSet for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)

Source

impl<T1: 'static + Send, T2: 'static + Send, T3: 'static + Send, T4: 'static + Send, T5: 'static + Send, T6: 'static + Send, T7: 'static + Send, T8: 'static + Send, T9: 'static + Send> ResourceSet for (T1, T2, T3, T4, T5, T6, T7, T8, T9)

Source

impl<T1: 'static + Send, T2: 'static + Send, T3: 'static + Send, T4: 'static + Send, T5: 'static + Send, T6: 'static + Send, T7: 'static + Send, T8: 'static + Send> ResourceSet for (T1, T2, T3, T4, T5, T6, T7, T8)

Source

impl<T1: 'static + Send, T2: 'static + Send, T3: 'static + Send, T4: 'static + Send, T5: 'static + Send, T6: 'static + Send, T7: 'static + Send> ResourceSet for (T1, T2, T3, T4, T5, T6, T7)

Source

impl<T1: 'static + Send, T2: 'static + Send, T3: 'static + Send, T4: 'static + Send, T5: 'static + Send, T6: 'static + Send> ResourceSet for (T1, T2, T3, T4, T5, T6)

Source

impl<T1: 'static + Send, T2: 'static + Send, T3: 'static + Send, T4: 'static + Send, T5: 'static + Send> ResourceSet for (T1, T2, T3, T4, T5)

Source

impl<T1: 'static + Send, T2: 'static + Send, T3: 'static + Send, T4: 'static + Send> ResourceSet for (T1, T2, T3, T4)

Source

impl<T1: 'static + Send, T2: 'static + Send, T3: 'static + Send> ResourceSet for (T1, T2, T3)

Source

impl<T1: 'static + Send, T2: 'static + Send> ResourceSet for (T1, T2)

Implementors