pub struct PresentedFrame { /* private fields */ }Expand description
A snapshot of a frame that has been presented by an app.
Returned by Rgb565FrameDisplay::active_frame. The display task should
compare token values to detect when a new frame is available.
Implementations
Sourceimpl PresentedFrame
impl PresentedFrame
Sourcepub fn with_pixels<R>(&self, f: impl FnOnce(&[Rgb565Pixel]) -> R) -> R
pub fn with_pixels<R>(&self, f: impl FnOnce(&[Rgb565Pixel]) -> R) -> R
Access the pixel slice of the frame for rendering.